update_database: Update jobs database

View source: R/update_database.R

update_databaseR Documentation

Update jobs database

Description

Performs the Civil Service Jobs scrape - cleans the new data

Usage

update_database(civil_service_user = T)

Arguments

civil_service_user

Are yoy a Civil Service User - if you are - you will need your username and password in the working directory as an R file called user_name_and_password.R with the structure: username = [CSJ username] password = [CSJ password]


TWJolly/CivilServiceR documentation built on May 16, 2022, 5:45 a.m.