View source: R/clean_and_combine.R
| clean_and_combine_raw_data | R Documentation |
The folder for the raw data is defined by the get paths function. This function loads that data then cleans it (reformats columns and extracts relevent data)
clean_and_combine_raw_data(save_in_app = T, re_clean_all = F)
save_in_app |
Should you save a new version of the cleaned data into the Shiny app folder? |
re_clean_all |
Should all raw data be put through the cleaning process or just the data that has not been cleaned thus far |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.