View source: R/update_database.R
| update_database | R Documentation |
Performs the Civil Service Jobs scrape - cleans the new data
update_database(civil_service_user = T)
civil_service_user |
Are yoy a Civil Service User - if you are - you will need your username and password in the working directory as an R file called user_name_and_password.R with the structure: username = [CSJ username] password = [CSJ password] |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.